==> phrase-2.0.1.tar.gz: test/src/phrase_prefs_test.dart <==
import 'package:mock_data/mock_data.dart';
import 'package:mockito/annotations.dart';
import 'package:mockito/mockito.dart';
import 'package:phrase/src/phrase_prefs.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:test/test.dart';
import 'package:uuid/uuid.dart';

import 'phrase_prefs_test.mocks.dart';

@GenerateMocks([
  SharedPreferences,
  Uuid,
])
void main() {
  group('PhrasePrefs', () {
    final sharedPrefsMock = MockSharedPreferences();
    final uuidGeneratorMock = MockUuid();
    final prefs = PhrasePrefs(
      getSharedPreferencesCallback: () async => sharedPrefsMock,
      uuid: uuidGeneratorMock,
    );

    setUp(() {
      reset(sharedPrefsMock);
      reset(uuidGeneratorMock);

      when(sharedPrefsMock.setString(any, any)).thenAnswer((_) async => true);
    });

    group('getUUID', () {
      test('returns existing uuid when it is saved', () async {
        final uuid = mockUUID();

        when(sharedPrefsMock.getString(any)).thenReturn(uuid);

        final result = await prefs.getUUID();

        expect(result, uuid);
        verify(sharedPrefsMock.getString(PhrasePrefs.kKeyUuid));
        verifyZeroInteractions(uuidGeneratorMock);
        verifyNoMoreInteractions(sharedPrefsMock);
      });

      test('generates and returns new uuid when none is yet saved', () async {
        final uuid = mockUUID();

        when(uuidGeneratorMock.v4()).thenReturn(uuid);
        when(sharedPrefsMock.getString(any)).thenReturn(null);

        final result = await prefs.getUUID();

        expect(result, uuid);
        verify(uuidGeneratorMock.v4());
        verify(sharedPrefsMock.getString(PhrasePrefs.kKeyUuid));
        verify(sharedPrefsMock.setString(PhrasePrefs.kKeyUuid, uuid));
        verifyNoMoreInteractions(uuidGeneratorMock);
        verifyNoMoreInteractions(sharedPrefsMock);
      });
    });

    group('getLastUpdate', () {
      test('returns saved value', () async {
        final expectedValue = DateTime.now().toString();
        when(sharedPrefsMock.getString(any)).thenReturn(expectedValue);

        final result = await prefs.getLastUpdate();

        expect(result, expectedValue);
        verify(sharedPrefsMock.getString(PhrasePrefs.kKeyLastUpdate));
        verifyNoMoreInteractions(sharedPrefsMock);
        verifyZeroInteractions(uuidGeneratorMock);
      });

      test('returns null if no value saved', () async {
        when(sharedPrefsMock.getString(any)).thenReturn(null);

        final result = await prefs.getLastUpdate();

        expect(result, null);
        verify(sharedPrefsMock.getString(PhrasePrefs.kKeyLastUpdate));
        verifyNoMoreInteractions(sharedPrefsMock);
        verifyZeroInteractions(uuidGeneratorMock);
      });
    });

    group('setLastUpdate', () {
      test('update last update time', () async {
        final value =
            (DateTime.now().millisecondsSinceEpoch / 1000).round().toString();
        await prefs.setLastUpdate();
        verify(sharedPrefsMock.setString(PhrasePrefs.kKeyLastUpdate, value));
        verifyNoMoreInteractions(sharedPrefsMock);
        verifyZeroInteractions(uuidGeneratorMock);
      });
    });

    group('version', () {
      const localeHash = 'dist_id-env_id-de';
      const key = 'phrase_version_$localeHash';
      group('get', () {
        test('returns saved value', () async {
          const version = '1';

          when(sharedPrefsMock.getString(any))
              .thenAnswer((realInvocation) => version);

          final result = await prefs.getVersion(localeHash);

          expect(result, version);
          verify(sharedPrefsMock.getString(key));
          verifyNoMoreInteractions(sharedPrefsMock);
          verifyZeroInteractions(uuidGeneratorMock);
        });

        test('returns null if no version saved', () async {
          when(sharedPrefsMock.getString(any))
              .thenAnswer((realInvocation) => null);

          final result = await prefs.getVersion(localeHash);

          expect(result, null);
          verify(sharedPrefsMock.getString(key));
          verifyNoMoreInteractions(sharedPrefsMock);
          verifyZeroInteractions(uuidGeneratorMock);
        });
      });

      group('set', () {
        test('saves version in shared preferences', () async {
          const version = '1';

          await prefs.setVersion(localeHash, version);

          verify(sharedPrefsMock.setString(key, version));
          verifyNoMoreInteractions(sharedPrefsMock);
          verifyZeroInteractions(uuidGeneratorMock);
        });
      });
    });
  });
}

==> phrase-2.4.0.tar.gz: test/src/phrase_prefs_test.dart <==
import 'package:mock_data/mock_data.dart';
import 'package:mockito/annotations.dart';
import 'package:mockito/mockito.dart';
import 'package:phrase/src/phrase_prefs.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:test/test.dart';
import 'package:uuid/uuid.dart';

import 'phrase_prefs_test.mocks.dart';

@GenerateMocks([
  SharedPreferences,
  Uuid,
])
void main() {
  group('PhrasePrefs', () {
    final sharedPrefsMock = MockSharedPreferences();
    final uuidGeneratorMock = MockUuid();
    final prefs = PhrasePrefs(
      getSharedPreferencesCallback: () async => sharedPrefsMock,
      uuid: uuidGeneratorMock,
    );

    setUp(() {
      reset(sharedPrefsMock);
      reset(uuidGeneratorMock);

      when(sharedPrefsMock.setString(any, any)).thenAnswer((_) async => true);
    });

    group('getUUID', () {
      test('returns existing uuid when it is saved', () async {
        final uuid = mockUUID();

        when(sharedPrefsMock.getString(any)).thenReturn(uuid);

        final result = await prefs.getUUID();

        expect(result, uuid);
        verify(sharedPrefsMock.getString(PhrasePrefs.kSdkInstallUuidKey));
        verifyZeroInteractions(uuidGeneratorMock);
        verifyNoMoreInteractions(sharedPrefsMock);
      });

      test('generates and returns new uuid when none is yet saved', () async {
        final uuid = mockUUID();

        when(uuidGeneratorMock.v4()).thenReturn(uuid);
        when(sharedPrefsMock.getString(any)).thenReturn(null);

        final result = await prefs.getUUID();

        expect(result, uuid);
        verify(uuidGeneratorMock.v4());
        verify(sharedPrefsMock.getString(PhrasePrefs.kSdkInstallUuidKey));
        verify(sharedPrefsMock.setString(PhrasePrefs.kSdkInstallUuidKey, uuid));
        verifyNoMoreInteractions(uuidGeneratorMock);
        verifyNoMoreInteractions(sharedPrefsMock);
      });
    });

    group('getLastUpdate', () {
      test('returns saved value', () async {
        final expectedValue = DateTime.now().toString();
        when(sharedPrefsMock.getString(any)).thenReturn(expectedValue);

        final result = await prefs.getLastUpdate();

        expect(result, expectedValue);
        verify(sharedPrefsMock.getString(PhrasePrefs.kLastUpdateKey));
        verifyNoMoreInteractions(sharedPrefsMock);
        verifyZeroInteractions(uuidGeneratorMock);
      });

      test('returns null if no value saved', () async {
        when(sharedPrefsMock.getString(any)).thenReturn(null);

        final result = await prefs.getLastUpdate();

        expect(result, null);
        verify(sharedPrefsMock.getString(PhrasePrefs.kLastUpdateKey));
        verifyNoMoreInteractions(sharedPrefsMock);
        verifyZeroInteractions(uuidGeneratorMock);
      });
    });

    group('setLastUpdate', () {
      test('update last update time', () async {
        final value =
            (DateTime.now().millisecondsSinceEpoch / 1000).round().toString();
        await prefs.setLastUpdate();
        verify(sharedPrefsMock.setString(PhrasePrefs.kLastUpdateKey, value));
        verifyNoMoreInteractions(sharedPrefsMock);
        verifyZeroInteractions(uuidGeneratorMock);
      });
    });

    group('version', () {
      const localeHash = 'dist_id-env_id-de';
      const key = 'phrase_version_$localeHash';
      group('get', () {
        test('returns saved value', () async {
          const version = '1';

          when(sharedPrefsMock.getString(any))
              .thenAnswer((realInvocation) => version);

          final result = await prefs.getVersion(localeHash);

          expect(result, version);
          verify(sharedPrefsMock.getString(key));
          verifyNoMoreInteractions(sharedPrefsMock);
          verifyZeroInteractions(uuidGeneratorMock);
        });

        test('returns null if no version saved', () async {
          when(sharedPrefsMock.getString(any))
              .thenAnswer((realInvocation) => null);

          final result = await prefs.getVersion(localeHash);

          expect(result, null);
          verify(sharedPrefsMock.getString(key));
          verifyNoMoreInteractions(sharedPrefsMock);
          verifyZeroInteractions(uuidGeneratorMock);
        });
      });

      group('set', () {
        test('saves version in shared preferences', () async {
          const version = '1';

          await prefs.setVersion(localeHash, version);

          verify(sharedPrefsMock.setString(key, version));
          verifyNoMoreInteractions(sharedPrefsMock);
          verifyZeroInteractions(uuidGeneratorMock);
        });
      });
    });
  });
}
